variable "base_hostname" {
  type = string
  description = "Base hostname to serve content from"
  default = "dev.homelab"
}

variable "count" {
  type = number
  default = 2
}

job "whoami" {
  region = "global"
  datacenters = ["dc1"]

  type = "service"

  group "whoami" {
    count = var.count

    constraint {
      operator = "distinct_hosts"
      value = "true"
    }

    network {
      mode = "bridge"
      port "web" {
        host_network = "loopback"
        to = 80
      }
    }

    service {
      port = "web"

      connect {
        sidecar_service {
          proxy {
            local_service_port = 80
          }
        }

        sidecar_task {
          resources {
            cpu    = 50
            memory = 50
          }
        }
      }

      check {
        type = "http"
        path = "/health"
        port = "web"
        interval = "10s"
        timeout = "10s"
      }

      tags = [
        "traefik.enable=true",
        "traefik.http.routers.whoami.entrypoints=web,websecure",
        "traefik.http.routers.whoami.rule=Host(`whoami.${var.base_hostname}`)",
        "traefik.http.routers.whoami.tls=true",
      ]
    }

    task "whoami" {
      driver = "docker"

      config {
        image = "containous/whoami:latest"
        ports = ["web"]
        args = ["--port", "${NOMAD_PORT_web}"]
      }

      resources {
        cpu = 50
        memory = 50
      }
    }
  }
}
